from Moodipy.SpotifyAuthorization import Authorization
from Moodipy.UserSummary import Person
import random


def generatePlaylist():

    """
    Step 0: Get Users Liked Songs
    """
    user, client = Authorization()
    print("checkpoint 0")

    user_songs = user.get_user_saved_tracks()

    print("checkpoint 1")

    """
    Step 1: Get Tracks Matching User Emotion
    """
    if len(Person.currentmood) == 1:
        first_emotion = Person.currentmood[0]
        second_emotion = None
    else:
        first_emotion = Person.currentmood[0]
        second_emotion = Person.currentmood[1]

    emotion_tracks = user.get_user_emotion_tracks(client=client, user_tracks=user_songs, base_emotion=first_emotion,
                                                  second_emotion=second_emotion)

    print("checkpoint 2")

    """
    Step 2: Create a Playlist for the User
    """
    emotion_tracks = random.sample(emotion_tracks, 25)

    tracks = {}
    for track in emotion_tracks:
        tracks[track['name']] = track['artists'][0]['name']


    Person.playlistName = Person.setPlaylistName(Person, Person.moodLabel, Person.currentmood)
    playlist_name = Person.playlistName

    description = "Enjoy your \"" + Person.moodLabel + "\" Playlist generated by Moodipy, an app that uses sentiment " \
                                                     "analysis to create a playlist that matches someone's mood. "

    user.create_playlist(playlist_name=playlist_name, description=description)
    print("checkpoint 3")

    """
    Step 3: Add Songs to a Playlist
    """
    user.add_to_playlist(playlist_name=playlist_name, playlist_tracks=emotion_tracks)
    print("checkpoint 4")

    return tracks



from PyQt5.QtWidgets import *
from PyQt5.QtGui import *
from PyQt5.QtCore import *
from Moodipy.UserSummary import Person
from Moodipy.PlaylistGUI import PlaylistPg
from screeninfo import get_monitors
import time

class LoadPg(QMainWindow):
    def __init__(self):
        super().__init__()
        self.title = "Load Page"
        self.desktop = QApplication.desktop()
        self.left = 0
        self.top = 0
        self.width = get_monitors()[0].width - 150
        self.height = get_monitors()[0].height - 80
        self.initUI()

    def initUI(self):
        self.sw = (self.width / 1000)
        self.sh = (self.height / 610)
        self.setWindowTitle(self.title)
        self.setGeometry(self.top, self.left, self.width, self.height)
        self.setStyleSheet("background-color: #d4d4ff")
        self.loadingBar = QProgressBar(self)
        self.loadingBar.setStyleSheet("background-color: #d4d4ff")
        self.loadingBar.setGeometry(self.sw*400, self.sh*420, self.sw*200, self.sh*25)
        self.startBtn = QPushButton("Start", self)
        self.startBtn.move(self.sw*453, self.sh*460)
        self.startBtn.clicked.connect(self.startProgressBar)
        self.mood_window()
        self.show()

    def mood_window(self):
        # Labels
        Person.setLabel(self, "Generating your", True, self.sw*390, self.sh*200, self.sw*220, self.sh*35, self.sw*19, "white", False, 'Segoe UI')
        Person.moodLabel = Person.setMoodLabel(Person, Person.currentmood)
        Person.setLabel(self, Person.moodLabel, True, self.sw*270, self.sh*260, self.sw*450, self.sh*58, self.sw*25, "white", True, 'Segoe UI')
        Person.setLabel(self, "Playlist", True, self.sw*385, self.sh*330, self.sw*220, self.sh*35, self.sw*19, "white", False, 'Segoe UI')

    def startProgressBar(self):
        for i in range(100):
            time.sleep(0.05)
            self.loadingBar.setValue(i)

        self.nextPg = PlaylistPg()
        self.nextPg.show()
        self.hide()


    def paintEvent(self, event):
        paint = QPainter(self)
        paint.setPen(QPen(Qt.white, 5, Qt.SolidLine))
        paint.setBrush(QBrush(Qt.white, Qt.SolidPattern))
        paint.drawEllipse(self.sw*270, self.sh*70, self.sw*450, self.sh*450)



from PyQt5.QtWidgets import *
from Moodipy.UserSummary import Person
from Moodipy.MoodAnalyzerGUI import MoodAnalyzerPg
from Moodipy.SpotifyAuthorization import Authorization
from screeninfo import get_monitors


class UserLoginPG(QMainWindow):
    def __init__(self):
        super().__init__()
        self.title = "Login"
        self.desktop = QApplication.desktop()
        self.left = 0
        self.top = 0
        self.width = get_monitors()[0].width - 150
        self.height = get_monitors()[0].height - 80
        self.initUI()

    def initUI(self):
        self.sw = (self.width / 1000)
        self.sh = (self.height / 610)
        self.setWindowTitle(self.title)
        self.setGeometry(self.top, self.left, self.width, self.height)
        self.setStyleSheet("background-color: #ccccff")
        self.mood_window()
        self.show()

    def mood_window(self):
        Person.setLabel(self, "", True, self.sw*290, self.sh*100, self.sw*460, self.sh*400, 0, "#f2ccff", False, 'Consolas')
        Person.setLabel(self, "Log In", False, self.sw*470, self.sh*130, self.sw*100, self.sh*39, self.sw*20, "#f2ccff", True, 'Consolas')
        Person.setLabel(self, "Login here using your Spotify username", False, self.sw*400, self.sh*170, self.sw*300, self.sh*39, self.sw*8, "#f2ccff", False, 'Consolas')
        Person.setLabel(self, "Username", False, self.sw*380, self.sh*230, self.sw*100, self.sh*30, self.sw*13, "#f2ccff", False, 'Consolas')
        self.username = QLineEdit(self)
        self.username.setGeometry(self.sw*380, self.sh*260, self.sw*270, self.sh*29)
        self.username.setStyleSheet("background-color: white")

        loginbtn = QPushButton("LOGIN", self)
        loginbtn.setGeometry(self.sw*450, self.sh*380, self.sw*150, self.sh*40)
        loginbtn.setStyleSheet("color: rgb(255, 255, 255); background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:0, stop:0 #ccccff, stop:1 rgb(240, 53, 218)); border-style: solid; border-radius:20px;")
        loginbtn.clicked.connect(self.on_click)

    def on_click(self):
        Person.userID = (self.username.text())
        if Authorization() == None:
            self.pop_up()
        else:
            f = open("UserInfo.txt", "w+")
            f.write(self.username.text())
            f.close()
            self.nextPg = MoodAnalyzerPg()
            self.nextPg.show()
            self.hide()

    def pop_up(self):
        msg = QMessageBox.question(self, 'Invalid Username', 'Please enter a valid username', QMessageBox.Ok)





import requests.exceptions
import spotipy
from Moodipy.Spotipy import Spotify, User
from Moodipy.UserSummary import Person


# Spotify Web API authorization

def Authorization():
    # Moodipy Client Environment Variables
    client_id = "17c9e6c9abe14de9bbfbb10c7d89afa4"
    client_secret = "1a8fdfd3501a4c2da9e6bd3fe300b7c8"
    redirect_uri = "http://localhost:8080"

    # User Environent Variables

    user_id = Person.userID

    scope = "user-library-read  playlist-modify-public user-top-read user-follow-read"

    # INTERFACE
    try:
        client = Spotify(client_id=client_id, client_secret=client_secret, redirect_uri=redirect_uri)
        user = User(user_id=user_id, scope=scope, client=client)
        #user.create_playlist("test", True, False, "tesing this broooo")
        return user, client
    except (spotipy.exceptions.SpotifyException, requests.exceptions.HTTPError,spotipy.oauth2.SpotifyOauthError):
        return None




import string

from nltk.tag import pos_tag
from nltk.corpus import stopwords
from nltk.stem import WordNetLemmatizer
from nltk.tokenize import word_tokenize
from collections import Counter


def find_mood(entry):
    # First we then make the entire journal entry lower-case
    temp_lower = entry.lower()
    # Finally, we remove all the punctuation from the entry
    journal_entry = temp_lower.translate(str.maketrans('', '', string.punctuation))

    # Now that we have a cleaned journal entry, we can tokenize the words
    tokenized_entry = word_tokenize(journal_entry, "english")

    # And then we remove 'stop words,' or common words that don't have any information/emotion attached to them
    final_entry = []
    for word in tokenized_entry:
        if word not in stopwords.words('english'):
            final_entry.append(word)

    # Now that we have all the important words from the entry, we can preform lemmatization, or the process of
    # turning plural words into singular words, turning verbs into their base form, etc.
    # We want to get the part-of-speech of the word so we can lemmatize it properly, otherwise it'll be treated
    # as a noun always.
    lemma_entry = []
    for word, tag in pos_tag(final_entry):
        if tag.startswith('N'):
            lemma_word = WordNetLemmatizer().lemmatize(word, pos='n')
        elif tag.startswith('V'):
            lemma_word = WordNetLemmatizer().lemmatize(word, pos='v')
        elif tag.startswith('J'):
            lemma_word = WordNetLemmatizer().lemmatize(word, pos='a')
        lemma_entry.append(lemma_word)

    # Finally, we can compare the words we have to our emotion list and identify which two emotions are most prevalent!

    # First we go through the emotions file and compare the words there with the words in our journal entry
    potential_emotions = []
    with open('Moodipy/emotions.txt') as file:
        for line in file:
            stripped_line = line.replace('\n', '').replace(',', '').replace('\'', '').replace(' ', '').strip()
            word, emotion = stripped_line.split(':')

            if word in lemma_entry:
                potential_emotions.append(emotion)

    # Then, we go through all the emotions we found and see which is most common
    emotion = Counter(potential_emotions)

    if len(emotion.most_common(2)) > 0:
        emotions_list = []
        for i in emotion.most_common(2):
            emotions_list.append(i[0])
        return emotions_list
    else:
        return None



from PyQt5.QtWidgets import *
from PyQt5.QtGui import *
from PyQt5.QtCore import *

class Person:
    def __init__(self):
        self.__currentMood = []
        self.__userID = None
        self.__moodLabel = None
        self.__playlistName = None
        self.__tracks = {}

    @property
    def playlistName(self):
        return self.__playlistName

    @playlistName.setter
    def playlistName(self, title):
       self.__playlistName = title

    def setPlaylistName(self, label, currMood):
        playlistName = ''
        if label == "Happy" or currMood[0] == "joy":
            playlistName = "Happy Vibes"
        elif label == "Awful" or currMood[0] == "sadness":
            playlistName = "Downbeat and Angst"
        elif label == "Bad" or currMood[0] == "anger":
            playlistName = "Rage and Loathing"
        elif label == "Okay" or currMood[0] == "fear":
            playlistName = "It's Gonna be Okayyy"
        elif label == "Excited" or currMood[0] == "surprise":
            playlistName = "Hyped Up!"
        elif "Love" in label:
            playlistName = "In Love with Life"
        return playlistName

    @property
    def moodLabel(self):
        return self.__moodLabel

    @moodLabel.setter
    def moodLabel(self, label):
        self.__moodLabel = label

    def setMoodLabel(self, currMood):
        if len(currMood) == 1:
            moodLabel = currMood[0].capitalize()
        else:
            moodLabel = currMood[0].capitalize() + " and " + currMood[1].capitalize()
        return moodLabel

    @property
    def currentmood(self):
        return self.__currentMood

    @property
    def tracks(self):
        return self.__tracks

    @tracks.setter
    def tracks(self, tracks):
        self.__tracks = tracks

    @property
    def moods(self):
        return self.__moods

    @currentmood.setter
    def currentmood(self, currentMood):
        self.__currentMood = currentMood

    @property
    def userID(self):
        return self.__userID

    @userID.setter
    def userID(self, userID):
        self.__userID = userID

    def setLabel(self, text, center, left, top, width, height, ftSize, bkColor, bold, font):
        label = QLabel(text, self)
        if center:
            label.setAlignment(Qt.AlignCenter)
        label.setGeometry(left, top, width, height)
        style = "background-color: "+bkColor+";"
        if bold:
            style = style+"font-weight: bold"
        label.setStyleSheet(style)
        label.setFont(QFont(font, ftSize))





from screeninfo import get_monitors
from PyQt5.QtWidgets import *
from PyQt5.QtGui import *
from PyQt5.QtCore import *
from Moodipy.moodAnalyzer import find_mood
from Moodipy.UserSummary import Person
from Moodipy.LoadPage import LoadPg

class MoodAnalyzerPg(QMainWindow):
    def __init__(self):
        super().__init__()
        self.title = "Mood Analyzer"
        self.desktop = QApplication.desktop()
        self.left = 0
        self.top = 0
        self.width = get_monitors()[0].width - 150
        self.height = get_monitors()[0].height - 80
        self.initUI()

    def initUI(self):
        self.sw = (self.width / 1000)
        self.sh = (self.height / 610)
        self.setWindowTitle(self.title)
        self.setGeometry(self.top, self.left, self.width, self.height)
        self.setStyleSheet("background-color:#abbdff")
        self.mood_window()
        self.show()

    def mood_window(self):
        # Labels
        Person.setLabel(self,"How are you feeling?", False, self.sw*20, self.sh*10, self.sw*370, self.sh*39, self.sw*20, "#abbdff", True, 'Segoe UI')
        Person.setLabel(self,"Write about your day...", False, self.sw*120, self.sh*70, self.sw*300, self.sh*35, self.sw*15, "#abbdff", False, 'Segoe UI')
        Person.setLabel(self, "Find your mood", False, self.sw*670, self.sh*70, self.sw*300, self.sh*35, self.sw*15, "#abbdff", False, 'Segoe UI')
        Person.setLabel(self, "", False, self.sw*20, self.sh*58, self.sw*320, self.sh*3, 0, "black", False, 'Segoe UI')
        # Textbox
        self.text = QTextEdit(self)
        self.text.setGeometry(self.sw*60, self.sh*100, self.sw*350, self.sh*450)
        self.text.setStyleSheet("border: 30px solid; border-radius:60px; background-color: #99acff; border-color: #99acff")
        self.text.setFont(QFont('Segoe UI', self.sw*11))
        # Block design
        boxDesign = QLabel(self)
        boxDesign.setGeometry(self.sw*570, self.sh*100, self.sw*350, self.sh*450)
        boxDesign.setStyleSheet("border: 30px solid; border-radius:60px; background-color: #99acff; border-color: #99acff")
        # OR label

        orLabel = QLabel("OR", self)
        orLabel.setAlignment(Qt.AlignCenter)
        orLabel.setGeometry(self.sw*460, self.sh*300, self.sw*60, self.sh*60)
        orLabel.setStyleSheet("border-radius: 30px; background-color: #99acff; border-color: #99acff; font-weight: bold")
        orLabel.setFont(QFont('Segoe UI', self.sw*12))


        # Text submit button
        btn1 = QPushButton("submit", self)
        btn1.clicked.connect(self.on_click)
        btn1.setGeometry(self.sw*200, self.sh*500, self.sw*80, self.sh*20)
        btn1.setStyleSheet("background-color: #abbdff;border-radius:10px; ")
        # Mood slider
        mood_slider = QSlider(Qt.Horizontal, self)
        mood_slider.setRange(0, 5)
        mood_slider.setGeometry(self.sw*630, self.sh*400, self.sw*250, self.sh*30)
        mood_slider.setFocusPolicy(Qt.NoFocus)
        mood_slider.setPageStep(1)
        mood_slider.valueChanged.connect(self.updateMood)
        mood_slider.setStyleSheet("background-color: #99acff;")
        # Mood image
        self.mood_img = QLabel(self)
        self.mood_img.setGeometry(self.sw*690, self.sh*200, self.sw*130, self.sh*130)
        self.mood_img.setStyleSheet("border-image : url(Moodipy/imgs/awful.jpeg);background-color: #99acff;")
        # Mood label
        self.mood = QLabel('awful', self)
        self.mood.setGeometry(self.sw*740, self.sh*350, self.sw*50, self.sh*30)
        self.mood.setMinimumWidth(self.sw*80)
        self.mood.setStyleSheet("background-color: #99acff;")
        self.mood.setFont(QFont('Segoe UI', self.sw*11))
        # Mood submit button
        btn2 = QPushButton("submit", self)
        btn2.clicked.connect(self.on_click2)
        btn2.setGeometry(self.sw*720, self.sh*500, self.sw*80, self.sh*20)
        btn2.setStyleSheet("background-color: #abbdff;border-radius:10px; ")

    def updateMood(self, value):
        moods = ["awful", "bad", "okay", "happy", "excited", "love"]
        self.mood_img.setStyleSheet("border-image : url(Moodipy/imgs/%s.jpeg);" % moods[value])
        self.mood.setText(moods[value])

    def on_click(self):
        Person.currentmood = find_mood(self.text.toPlainText())
        if Person.currentmood is None:
            print("Please be more descriptive")
            self.pop_up()
        else:
            self.nextPg = LoadPg()
            self.nextPg.show()
            self.hide()

    def pop_up(self):
        msg = QMessageBox.question(self, 'Error', 'Please be more descriptive', QMessageBox.Ok)

    def on_click2(self):
        print("your mood: %s" % self.mood.text())
        mood = []
        mood.append(self.mood.text())
        Person.currentmood = mood
        self.nextPg = LoadPg()
        self.nextPg.show()
        self.hide()



from PyQt5.QtWidgets import *
from PyQt5.QtGui import *
from Moodipy.UserSummary import Person
from screeninfo import get_monitors
from Moodipy.PlaylistGenerator import generatePlaylist

class PlaylistPg(QMainWindow):
    def __init__(self):
        super().__init__()
        self.title = "Playlist"
        self.desktop = QApplication.desktop()
        self.left = 0
        self.top = 0
        self.width = get_monitors()[0].width - 150
        self.height = get_monitors()[0].height - 80
        self.initUI()

    def initUI(self):
        self.sw = (self.width / 1000)
        self.sh = (self.height / 610)
        self.setWindowTitle(self.title)
        self.setGeometry(self.top, self.left, self.width, self.height)
        self.setStyleSheet(
            "background-color:qlineargradient(spread:pad, x1:0, y1:1, x2:0, y2:0, stop:0 rgba(208, 255, 244, 255), stop:0.00507614 rgba(208, 255, 244, 255), stop:0.664865 rgba(208, 255, 244, 255), stop:0.666667 rgba(151, 223, 201, 255), stop:1 rgba(161, 223, 204, 255))")
        self.mood_window()
        self.show()

    def mood_window(self):
        Person.tracks = generatePlaylist()
        # Generate another playlist btn
        nextbtn = QPushButton("Enter another mood...", self)
        nextbtn.setStyleSheet("background-color:rgba(208, 255, 244, 255); font-weight: bold; border: 5px solid; border-color:white; hover { background-color : white}")
        nextbtn.setGeometry(self.sw*800, self.sh*20, self.sw*200, self.sh*30)
        nextbtn.clicked.connect(self.on_click)
        # Creates a playlist name
        Person.playlistName = Person.setPlaylistName(Person, Person.moodLabel, Person.currentmood)
        Person.setLabel(self, Person.playlistName, False, self.sw * 350, self.sh * 80, self.sw * 520, self.sh * 58, self.sw * 30, "rgba(161, 223, 204, 255)", True, "Segoe UI")
        # Tracks List Widget
        listWidget = QListWidget(self)
        listWidget.setGeometry(0, self.sh*200, self.width, self.sh*410)
        scrollBar = QScrollBar(self)
        listWidget.setVerticalScrollBar(scrollBar)
        listWidget.setStyleSheet("background-color:rgba(208, 255, 244, 255); ")

        tracks = Person.tracks
        # Add tracks to list widget
        num = 1
        for song, title in tracks.items():
            if num < 10:
                songtitle = QListWidgetItem(str(num) + "     " + song)
            else:
                songtitle = QListWidgetItem(str(num) + "   " + song)
            artist = QListWidgetItem("               " + title + "\n")
            songtitle.setFont(QFont("Segoe UI", self.sw * 20))
            artist.setFont(QFont("Segoe UI", self.sw * 10))
            listWidget.addItem(songtitle)
            listWidget.addItem(artist)
            num = num + 1
    # Add another Mood
    def on_click(self):
        from Moodipy.MoodAnalyzerGUI import MoodAnalyzerPg
        self.nextPg = MoodAnalyzerPg()
        self.nextPg.show()
        self.hide()




import spotipy
import spotipy.util as util
from spotipy.oauth2 import SpotifyClientCredentials


# Class for the Spotify Client
class Spotify(object):
    # Client Variables
    _client_id = None
    _client_secret = None
    _redirect_uri = None
    _spotify_client = None

    # Constructor
    def __init__(self, client_id=None, client_secret=None, redirect_uri=None):
        if client_id == None or client_secret == None:
            raise Exception("You must set client_id and client_secret")

        if redirect_uri == None:
            raise Exception("You must set a redirect_uri")

        self._client_id = client_id
        self._client_secret = client_secret
        self._redirect_uri = redirect_uri
        self._spotify_client = spotipy.Spotify(
            client_credentials_manager=SpotifyClientCredentials(client_id, client_secret))

        if not self._spotify_client:
            raise Exception("An error occurred on the client side")


# Class for the User
class User(Spotify):
    # User Variables
    _user_token = None
    _user_client = None
    _user_id = None

    # Constructor
    def __init__(self, user_id=None, scope=None, client=None):
        self._user_id = user_id
        self._user_token = util.prompt_for_user_token(user_id, scope, client._client_id, client._client_secret,
                                                      client._redirect_uri)
        self._user_client = spotipy.Spotify(auth=self._user_token)

        if not self._user_client:
            raise Exception("An error occurred granting access")

    # Returns a List of the Users Liked Songs
    def get_user_saved_tracks(self):
        i, items, results = 0, ['1'], []
        while (len(items) > 0):
            items = self._user_client.current_user_saved_tracks(50, 50 * i)['items']
            if (len(items) != 0):
                for item in items:
                    results.append(item['track'])

            i += 1
            if i > 10:  # FOR TESTING PURPOSES, 100 songs only
                break

        return results

    # Returns a List of the Users Songs Matching Emotion
    def get_user_emotion_tracks(self, client=None, user_tracks=None, base_emotion=None, second_emotion=""):
        emotion_tracks = []
        if base_emotion == "sadness" or base_emotion == "awful" or second_emotion == "sadness" or second_emotion == "awful":
            # float valence;                        //Metric of the positiveness of the track ( < 0.5 )
            # float energy;                         //Metric of the energy of the track ( < 0.5 )
            # bool mode;                            //Whether the track is major or minor (1 = minor?)
            # float instrumentalness;               //Metric of the track being instrumental ( > 0.5 )
            # float acousticness;                   //Metric of the track being acoustic ( > 0.5 )
            # float tempo;                          //The tempo of the track in ( < 120 BPM )
            for track in user_tracks:
                af = client._spotify_client.audio_features(track['id'])[0]
                if af['valence'] < 0.5 or af['energy'] < 0.5 or af['instrumentalness'] > 0.5 or af[
                    'acousticness'] > 0.5 or af['tempo'] < 120:
                    emotion_tracks.append(track)



        elif base_emotion == "bad" or base_emotion == "anger":
            # float loudness;                       //Metric of the loudness of the track ( > 0. 5 )
            # float energy;                         //Metric of the energy of the track ( > 0.5 )
            # float tempo;                          //The tempo of the track ( > 120 BPM )
            # float speechiness;                    //Metric of the track containing human voice ( > 0.5 )
            for track in user_tracks:
                af = client._spotify_client.audio_features(track['id'])[0]
                if af['loudness'] > 0.5 or af['energy'] > 0.5 or af['tempo'] > 120 or af[
                    'speechiness'] > 0.5:
                    emotion_tracks.append(track)

        elif base_emotion == "okay" or base_emotion == "fear":
            # float danceability;                   //Metric of the track being danceable ( < 0.5 )
            # float instrumentalness;               //Metric of the track being instrumental ( > 0.5 )
            # float loudness;                       //Metric of the loudness of the track ( > 0.5 )
            # float valence;                        //Metric of the positiveness of the track ( < 0.5 )
            # float energy;                         //Metric of the energy of the track ( <= 0.5)
            for track in user_tracks:
                af = client._spotify_client.audio_features(track['id'])[0]
                if af['danceability'] < 0.5 or af['instrumentalness'] > 0.5 or af['loudness'] > 0.5 or af[
                    'valence'] < 0.5 or af['energy'] <= 0.5:
                    emotion_tracks.append(track)

        elif base_emotion == "happy" or base_emotion == "joy":
            # float valence;                        //Metric of the positiveness of the track ( > 0.5 )
            # float danceability;                   //Metric of the track being danceable ( > 0.5 )
            # float energy;                         //Metric of the energy of the track ( > 0.5 )
            # float tempo;                          //The tempo of the track ( > 100 BPM )
            # float loudness;                       //Metric of the loudness of the track ( > 0.5)
            for track in user_tracks:
                af = client._spotify_client.audio_features(track['id'])[0]
                if af['valence'] > 0.5 or af['danceability'] > 0.5 or af['energy'] > 0.5 or af[
                    'tempo'] > 100 or af['loudness'] > 0.5:
                    emotion_tracks.append(track)

        elif base_emotion == "excited" or base_emotion == "surprise":
            # float energy;                         //Metric of the energy of the track ( > 0.5 )
            # float loudness;                       //Metric of the loudness of the track ( > 0.5 )
            # float tempo;                          //The tempo of the track ( > 120 BPM )
            # float danceability;                   //Metric of the track being danceable ( > 0.5 )
            for track in user_tracks:
                af = client._spotify_client.audio_features(track['id'])[0]
                if af['energy'] > 0.9 or af['loudness'] > 0.9 or af['tempo'] > 120 or af[
                    'danceability'] > 0.9:
                    emotion_tracks.append(track)

        elif base_emotion == "love":
            # float valence;                        //Metric of the positiveness of the track ( > 0.5 )
            # float tempo;                          //The tempo of the track ( < 120 BPM )
            # float instrumentalness;               //Metric of the track being instrumental ( < 0.5 )
            # bool mode;                            //Whether the track is major or minor (0 = major?)
            for track in user_tracks:
                af = client._spotify_client.audio_features(track['id'])[0]
                if af['valence'] > 0.5 or af['tempo'] < 120 or af['instrumentalness'] < 0.5 or af[
                    'mode'] == 0:
                    emotion_tracks.append(track)

        return emotion_tracks

    # Returns the ID of a Desired User Playlist
    def get_playlist_id(self, playlist_name=None):
        if playlist_name == None:
            raise Exception("You must enter a playlist name")

        playlist_id = None
        playlists = self._user_client.user_playlists(self._user_id)
        for playlist in playlists['items']:
            if playlist['name'] == playlist_name:
                playlist_id = playlist['id']

        if playlist_id == None:
            raise Exception("There is no playlist with that name")

        return playlist_id

    # Creates a New Playlist for the User
    def create_playlist(self, playlist_name=None, public=True, collaborative=False, description=""):
        if playlist_name == None:
            raise Exception("You must enter a playlist name")

        self._user_client.user_playlist_create(self._user_id, name=playlist_name, public=public,
                                               collaborative=collaborative, description=description)

    # Adds Tracks to a User's Playlist
    def add_to_playlist(self, playlist_name=None, playlist_tracks=None):
        if playlist_name == None:
            raise Exception("You must enter a playlist name")

        playlist_id = self.get_playlist_id(playlist_name=playlist_name)
        track_ids = []
        for track in playlist_tracks:
            track_ids.append(track['id'])

        self._user_client.user_playlist_add_tracks(self._user_id, playlist_id=playlist_id, tracks=track_ids)

        # for i in range(0, len(track_ids), 50):
        #     hundred_tracks = track_ids[i:i+50]
        #     self._user_client.user_playlist_add_tracks(self._user_id, playlist_id=playlist_id, tracks=hundred_tracks)


"""
    /* USER INPUT PARAMETERS */
    Values from 0 - 1
    float acousticness;                   //Metric of the track being acoustic
    float danceability;                   //Metric of the track being danceable
    float energy;                         //Metric of the energy of the track
    float instrumentalness;               //Metric of the track being instrumental
    float liveness;                       //Metric of the track sounding as a live performance
    float speechiness;                    //Metric of the track containing human voice
    float valence;                        //Metric of the positiveness of the track
    float tempo;                          //The tempo of the track in BPM as its reciprocal
    float loudness;                       //Metric of the loudness of the track
    bool mode;                            //Whether the track is major or minor
    float popularity;                     //Metric of the popularity of the track
"""



from setuptools import setup


setup(
    name="hellomood",
    version="0.107",
    packages=['hellomood',],
    url="https://github.com/dianas11xx/MoodipyTest",
    author="Noteworthy",
    license = "GPL 3",
    package_data = {"Moodipy":['*.jpeg', '*.png', '*.txt']},
    description="use sentiment analysis to create a playlist that matches someone's mood and also predict songs to rise in popularity.",
    install_requires=['nltk==3.6.2', 'screeninfo==0.6.7', 'spotipy==2.18.0', 'requests>=2.25.0', 'PyQt5>=5.12','urllib3>=1.26.0', 'PyQt5-sip>=4.19.19'],
    entry_points={"console_scripts": ["hellomood=Moodipy.main:main"]},
    include_package_data=True
)



import sys
import os
from PyQt5.QtWidgets import *
from PyQt5.QtGui import *
from PyQt5.QtCore import *
from Moodipy.UserSummary import Person
from Moodipy.UserLogin import UserLoginPG
from screeninfo import get_monitors
from Moodipy.MoodAnalyzerGUI import MoodAnalyzerPg


class MainWindow(QMainWindow):
    def __init__(self):
        super().__init__()
        self.title = "Moodipy"
        self.desktop = QApplication.desktop()
        self.left = 0
        self.top = 0
        self.width = get_monitors()[0].width - 150
        self.height = get_monitors()[0].height - 80
        self.initUI()


    def initUI(self):
        self.sw = (self.width / 1000)
        self.sh = (self.height / 610)
        self.setWindowTitle(self.title)
        self.setGeometry(self.top, self.left, self.width, self.height)
        self.setStyleSheet("background-color: #ffdb94")
        self.main_window()
        self.show()

    def main_window(self):
        print(self.width)
        print(self.height)
        button = QPushButton(self)
        button.setGeometry(self.sw*480, self.sh*450, self.sw*40, self.sh*20)
        button.setStyleSheet("border-image : url(Moodipy/imgs/arrow.png);")
        button.clicked.connect(self.nextPG)

        Person.setLabel(self, "Welcome to", True, self.sw*390, self.sh*200, self.sw*220, self.sh*35, self.sw*19, "white", False,'Consolas')
        Person.setLabel(self, "Moodipy", True, self.sw*380, self.sh*260, self.sw*230, self.sh*58, self.sw*35, "white", True, 'Segoe UI')
        Person.setLabel(self, "Generating playlists that express how you feel", True, self.sw*335, self.sh*375, self.sw*338, self.sh*20, self.sw*9, "white", False,'Consolas')

    def paintEvent(self, event):
        paint = QPainter(self)
        paint.setPen(QPen(Qt.white, 5, Qt.SolidLine))
        paint.setBrush(QBrush(Qt.white, Qt.SolidPattern))
        paint.drawEllipse(self.sw*270, self.sh*70, self.sw*450, self.sh*450)

    def nextPG(self):
        if os.path.isfile("UserInfo.txt"):
            if os.stat("UserInfo.txt").st_size == 0:
                self.nextPG = UserLoginPG()
                self.nextPG.show()
                self.hide()
            f = open("UserInfo.txt", "r+")
            Person.userID = f.readline()
            f.close()
            self.nextPG = MoodAnalyzerPg()
            self.nextPG.show()
            self.hide()
        else:
            self.nextPG = UserLoginPG()
            self.nextPG.show()
            self.hide()

def main():
    app = QApplication(sys.argv)
    window = MainWindow()
    sys.exit(app.exec())

if __name__ == "__main__":
    main()



from PyQt5.QtWidgets import *
from PyQt5.QtGui import *
from PyQt5.QtCore import *
from Moodipy.UserSummary import Person
from screeninfo import get_monitors


class MoodTrends(QMainWindow):
    def __init__(self):
        super().__init__()
        self.title = "Mood Trends"
        self.desktop = QApplication.desktop()
        self.left = 0
        self.top = 0
        self.width = get_monitors()[0].width - 150
        self.height = get_monitors()[0].height - 80
        self.initUI()

    def initUI(self):
        self.sw = (self.width / 1000)
        self.sh = (self.height / 610)
        self.setWindowTitle(self.title)
        self.setGeometry(self.top, self.left, self.width, self.height)
        self.setStyleSheet("background-color: #bdffcc")
        self.mood_window()
        self.show()

    def mood_window(self):

        Person.setLabel(self, "Mood Analysis", False, self.sw*20, self.sh*10, self.sw*370, self.sh*39, self.sw*20, "#bdffcc", True, 'Segoe UI')
        Person.setLabel(self, "Your Current Mood", False, self.sw*25, self.sh*100, self.sw*370, self.sh*39, self.sw*12, "#bdffcc", True, 'Segoe UI')
        Person.setLabel(self, "Your Mood Trends", False, self.sw*470, self.sh*330, self.sw*370, self.sh*39, self.sw*12, "#bdffcc", True, 'Segoe UI')
        Person.setLabel(self, "", False, self.sw*20, self.sh*58, self.sw*225, self.sh*3, 0, "black", False, 'Segoe UI')
        Person.setLabel(self, "", False, self.sw*25, self.sh*150, self.sw*480, self.sh*170, 0, "white", False, 'Segoe UI')
        Person.setLabel(self, "", False, self.sw*470, self.sh*370, self.sw*480, self.sh*170, 0, "white", False, 'Segoe UI')
        mood = ''
        if len(Person.currentmood) == 1:
            mood = Person.currentmood[0]
        else:
            mood = Person.currentmood[0] + " and " + Person.currentmood[1]

        Person.setLabel(self, mood, False, self.sw*90, self.sh*280, self.sw*150, self.sh*20, self.sw*11, "white", False, 'Consolas')




